# __init__.py
from os import chdir, getcwd, getenv
from os.path import abspath, dirname, expanduser
import os
from platform import system
import macos
from shell import shell

exists=os.path.exists("setup.py")

def islinux():
    return system()=="Linix"

def ismacos():
    return system()=="Darwin"

def iswindows():
    return system()=="Windows"

def fullname(f="setup.py"):
    """return "python setup.py --fullname" """
    f=abspath(expanduser(f))
    if os.path.exists(f):
        return shell("python %s --fullname" % f).splitlines()[-1]

def name():
    """return "python setup.py --name" """
    setup=abspath(expanduser("setup.py"))
    if os.path.exists(setup):
        return shell("python setup.py --name").splitlines()[-1]

def version():
    """return "python setup.py --version" """
    setup=abspath(expanduser("setup.py"))
    if os.path.exists(setup):
        return shell("python setup.py --version").splitlines()[-1]


def check(bin="python",f="setup.py"):
    """return True if "python setup.py check" succesfull """
    f=abspath(expanduser(f))
    if os.path.exists(f):
        pwd = getcwd()
        # change current dir to testing relative paths
        chdir(getenv("HOME")) 
        try:
            command="%s %s check" % (bin,f)
            shell(command)
            chdir(pwd) # return current dir
        except Exception, e:
            chdir(pwd) # return current dir
            raise Exception(str(e))
    return True

def install(bin="python",f="setup.py"):
    """run "python setup.py install" """
    f=abspath(expanduser(f))
    pwd = getcwd()
    if os.path.exists(f):
        print "f=",f
        try:
            chdir(dirname(f))
            print "chdir(dirname(f))=",dirname(f)
            if islinux():
                command="sudo %s %s install" % (bin,f)
                shell(command)
                return True
            if ismacos():
                command="sudo %s %s install" % (bin,f)
                macos.shell(command,True)
                return True
            if iswindows():
                shell("%s %s install" % (bin,f))
                return True
        except Exception:
            chdir(pwd)
        raise OSError("%s unsupported yet" % system())

def register(f="setup.py"):
    """run "python setup.py register" """
    f=abspath(expanduser(f))
    if os.path.exists(f):
        r=shell("python %s register" % f)
        if not r.find("Server response (200): OK")>0:
            raise Exception(r)

def upload(f="setup.py",distribution="sdist"):
    """run "python setup.py %s upload" """
    f=abspath(expanduser(f))
    if os.path.exists(f):
        register(f)
        command="python %s %s upload" % (f,distribution)
        result=shell(command)
        if result.find("Server response (200): OK")>0:
            return True
        if result.find("you should create a new release")>0:
            raise Exception(result.splitlines()[-2:])
        raise Exception(result)

#def bdist_upload(f="setup.py"):
    #return upload(f,"bdist")

def sdist_upload(f="setup.py"):
    return upload(f,"sdist")